(self.webpackJsonp=self.webpackJsonp||[]).push([[27],{726:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",function(){return c}),n.d(r,"codeMirrorCss",function(){return i});var s=n(462),o=n.n(s),t=n(677),a=(n(678),n(679),n(15));o.a.commands.save=(e=>{Object(a.a)(e.getWrapperElement(),"editor-save")});const c=o.a,i=t.a}}]);
//# sourceMappingURL=chunk.4a6d6443d07b637bc109.js.map